@@ -12,7 +12,7 @@ test_that("Check noctua s3 dplyr copy_to method",{
   con <- dbConnect(athena())
   
   # creates Athena table and returns tbl_sql
-  athena_mtcars <- copy_to(con, mtcars, s3_location = Sys.getenv("noctua_s3_tbl"), compress = T)
+  athena_mtcars <- copy_to(con, mtcars, s3_location = Sys.getenv("noctua_s3_tbl"), compress = T, overwrite = T)
   mtcars_filter <- athena_mtcars %>% filter(gear >=4)
   tbl_result <- is.tbl(mtcars_filter)
   # create another Athena table
@@ -28,11 +28,4 @@ test_that("Check noctua s3 dplyr copy_to method",{
   expect_true(tbl_result)
   expect_true(result1)
   expect_true(result2)
-  
-  # clean up system environmental variables
-  Sys.unsetenv("AWS_ACCESS_KEY_ID")
-  Sys.unsetenv("AWS_SECRET_ACCESS_KEY")
-  Sys.unsetenv("AWS_SESSION_TOKEN")
-  Sys.unsetenv("AWS_PROFILE")
-  Sys.unsetenv("AWS_REGION")
 })
